RequestPurchaseBuilder class

Unified purchase parameter builder

Available extensions

Constructors

RequestPurchaseBuilder()

Properties

android → RequestPurchaseAndroidBuilder
final
hashCode → int
The hash code for this object.
no setterinherited
ios → RequestPurchaseIosBuilder
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ProductQueryType
getter/setter pair

Methods

build() → RequestPurchaseProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withAndroid(AndroidPurchaseBuilder configure) → RequestPurchaseBuilder

Available on RequestPurchaseBuilder, provided by the RequestPurchaseBuilderExtension extension

withIOS(IosPurchaseBuilder configure) → RequestPurchaseBuilder

Available on RequestPurchaseBuilder, provided by the RequestPurchaseBuilderExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited