winBackOffer property
Win-back offer to apply when this builder is used with subscriptions (iOS 18+)
Implementation
WinBackOfferInputIOS? winBackOffer;
Win-back offer to apply when this builder is used with subscriptions (iOS 18+)
WinBackOfferInputIOS? winBackOffer;