RequestSubscriptionAndroidBuilder class

Builder for Android subscription props

Properties

hashCode → int
The hash code for this object.
no setterinherited
isOfferPersonalized ↔ bool?
getter/setter pair
obfuscatedAccountIdAndroid ↔ String?
getter/setter pair
obfuscatedProfileIdAndroid ↔ String?
getter/setter pair
purchaseTokenAndroid ↔ String?
getter/setter pair
replacementModeAndroid ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skus ↔ List<String>
getter/setter pair
subscriptionOffers ↔ List<AndroidSubscriptionOfferInput>
getter/setter pair

Methods

build() → RequestSubscriptionAndroidProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited