ConnectionResult class

Legacy connection event payload.

Use the result of initConnection. Scheduled for removal in flutter_inapp_purchase 10.0.0.

Annotations
  • @Deprecated('Use the result of initConnection. ' 'Scheduled for removal in flutter_inapp_purchase 10.0.0.')

Constructors

ConnectionResult({String? msg})
ConnectionResult.fromJSON(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
msg String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited