AdvancedCommerceItemIOS class

An item purchased through the Advanced Commerce API (iOS 18.4+). Represents a developer-defined product within a generic SKU transaction.

Constructors

AdvancedCommerceItemIOS({AdvancedCommerceItemDetailsIOS? details, List<AdvancedCommerceRefundIOS>? refunds, double? revocationDate})
const
AdvancedCommerceItemIOS.fromJson(Map<String, dynamic> json)
factory

Properties

details AdvancedCommerceItemDetailsIOS?
The item's detail information
final
hashCode int
The hash code for this object.
no setterinherited
refunds List<AdvancedCommerceRefundIOS>?
Refunds issued for this item, if any
final
revocationDate double?
Date access to this item was revoked (milliseconds since epoch)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited