AlternativeBillingModeAndroid enum

Alternative billing mode for Android Controls which billing system is used Use the user-choice-billing program for user choice billing and external-offer for external digital-content offers. @deprecated Use enableBillingProgramAndroid with BillingProgramAndroid instead. Scheduled for removal in OpenIAP 3.0.

Inheritance
Available extensions

Values

None → const AlternativeBillingModeAndroid

Standard Google Play billing (default)

const AlternativeBillingModeAndroid('none')
UserChoice → const AlternativeBillingModeAndroid

User choice billing - user can select between Google Play or alternative Requires Google Play Billing Library 7.0+ @deprecated Use the user-choice-billing BillingProgramAndroid value instead. Scheduled for removal in OpenIAP 3.0.

const AlternativeBillingModeAndroid('user-choice')
AlternativeOnly → const AlternativeBillingModeAndroid

Alternative billing only - no Google Play billing option Requires Google Play Billing Library 6.2+ @deprecated Use the external-offer BillingProgramAndroid value instead. Scheduled for removal in OpenIAP 3.0.

const AlternativeBillingModeAndroid('alternative-only')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AlternativeBillingModeAndroid>
A constant List of the values in this enum, in order of their declaration.