AppTransaction class

Constructors

AppTransaction({required double appId, String? appTransactionId, required String appVersion, required double appVersionId, required String bundleId, required String deviceVerification, required String deviceVerificationNonce, required String environment, required String originalAppVersion, String? originalPlatform, required double originalPurchaseDate, double? preorderDate, double? revocationDate, required double signedDate, String? storeType})
const
AppTransaction.fromJson(Map<String, dynamic> json)
factory

Properties

appId double
final
appTransactionId String?
final
appVersion String
final
appVersionId double
final
bundleId String
final
deviceVerification String
final
deviceVerificationNonce String
final
environment String
final
hashCode int
The hash code for this object.
no setterinherited
originalAppVersion String
final
originalPlatform String?
Original App Store platform raw value. Xcode 27 adds the back-deployed managed acquisition-platform value.
final
originalPurchaseDate double
final
preorderDate double?
final
revocationDate double?
Date the app-acquisition transaction was revoked (epoch milliseconds). Available through the Xcode 27 SDK and back-deployed to Apple 16+.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signedDate double
final
storeType String?
Store channel of the original app purchase: consumer, education, enterprise, or another future StoreKit value (Apple 27+ beta).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited