BillingChoiceImageLayoutAndroid enum

Play Billing choice image layout (Android) Available in OpenIAP Spec 2.1.0 / openiap-google 2.3.0 (requires Play Billing 9.1.0+).

Inheritance
Available extensions

Values

RectangularFourByOne → const BillingChoiceImageLayoutAndroid

Rectangular image with a 4:1 aspect ratio.

const BillingChoiceImageLayoutAndroid('rectangular-four-by-one')
RectangularThreeByOne → const BillingChoiceImageLayoutAndroid

Rectangular image with a 3:1 aspect ratio.

const BillingChoiceImageLayoutAndroid('rectangular-three-by-one')
RectangularTwoByTwo → const BillingChoiceImageLayoutAndroid

Rectangular image with a 2:2 aspect ratio.

const BillingChoiceImageLayoutAndroid('rectangular-two-by-two')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BillingChoiceImageLayoutAndroid>
A constant List of the values in this enum, in order of their declaration.