BillingChoiceInfoAndroid class

Display information for developer-rendered Billing Choice screens (Android) Available in OpenIAP Spec 2.1.0 / openiap-google 2.3.0 (requires Play Billing 9.1.0+).

Constructors

BillingChoiceInfoAndroid({required String playBillingChoiceImageUrl, String? playBillingLoyaltyInfo})
const
BillingChoiceInfoAndroid.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
playBillingChoiceImageUrl String
URL for the Play Billing choice image matching the requested layout.
final
playBillingLoyaltyInfo String?
Play Loyalty information for the user.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited