playBillingChoiceImageUrl property
URL for the Play Billing choice image matching the requested layout.
Implementation
final String playBillingChoiceImageUrl;
URL for the Play Billing choice image matching the requested layout.
final String playBillingChoiceImageUrl;