BillingProgramInformationDialogParamsAndroid class

Parameters for showing a billing program information dialog (Android) Available in OpenIAP Spec 2.1.0 / openiap-google 2.3.0 (requires Play Billing 9.1.0+).

Constructors

BillingProgramInformationDialogParamsAndroid({BillingProgramAndroid billingProgram = BillingProgramAndroid.BillingChoice, required String externalTransactionToken})
const
BillingProgramInformationDialogParamsAndroid.fromJson(Map<String, dynamic> json)
factory

Properties

billingProgram BillingProgramAndroid
Billing program. Currently only BILLING_CHOICE is supported.
final
externalTransactionToken String
External transaction token returned by the Billing Choice reporting-details flow.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited