externalTransactionToken property

String? externalTransactionToken
final

A pre-generated external transaction token for a Billing Choice external-link flow. Omit it when Google Play should provide the token in the callback.

Implementation

final String? externalTransactionToken;