linkUri property
The URI where the external payment will be processed. Required only when the selected billing program links outside the app.
Implementation
final String? linkUri;
The URI where the external payment will be processed. Required only when the selected billing program links outside the app.
final String? linkUri;