externalTransactionToken property
External transaction token used to report transactions made through developer billing. Nullable for flows such as external payments where no token is returned.
Implementation
final String? externalTransactionToken;
External transaction token used to report transactions made through developer billing. Nullable for flows such as external payments where no token is returned.
final String? externalTransactionToken;