purchaseOptionIdAndroid property
Android Purchase option ID for this offer.
Used to identify which purchase option the user selected.
Available in Google Play Billing Library 7.0+
Implementation
final String? purchaseOptionIdAndroid;
Android Purchase option ID for this offer.
Used to identify which purchase option the user selected.
Available in Google Play Billing Library 7.0+
final String? purchaseOptionIdAndroid;