ExternalOfferReportingDetailsAndroid class

External offer reporting details (Android) Available in Google Play Billing Library 6.2.0+, deprecated in 8.2.0 @deprecated Use BillingProgramReportingDetailsAndroid from createBillingProgramReportingDetailsAndroid instead. Scheduled for removal in OpenIAP 3.0.

Constructors

ExternalOfferReportingDetailsAndroid({required String externalTransactionToken})
const
ExternalOfferReportingDetailsAndroid.fromJson(Map<String, dynamic> json)
factory

Properties

externalTransactionToken String
External transaction token for reporting external offer transactions
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited