ExternalPurchaseNoticeResultIOS class

Result of presenting external purchase notice sheet (iOS 17.4+) Returns the token when user continues to external purchase.

Constructors

ExternalPurchaseNoticeResultIOS({String? error, String? externalPurchaseToken, required ExternalPurchaseNoticeAction result})
const
ExternalPurchaseNoticeResultIOS.fromJson(Map<String, dynamic> json)
factory

Properties

error → String?
Optional error message if the presentation failed
final
externalPurchaseToken → String?
External purchase token returned when user continues (iOS 17.4+). This token should be reported to Apple's External Purchase Server API. Only present when result is Continue.
final
hashCode → int
The hash code for this object.
no setterinherited
result → ExternalPurchaseNoticeAction
Notice result indicating user action
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited