GetBillingChoiceInfoParamsAndroid class

Parameters for fetching Billing Choice display information (Android) Available in OpenIAP Spec 2.1.0 / openiap-google 2.3.0 (requires Play Billing 9.1.0+).

Constructors

GetBillingChoiceInfoParamsAndroid({BillingProgramAndroid billingProgram = BillingProgramAndroid.BillingChoice, BillingChoiceImageLayoutAndroid playBillingChoiceImageLayout = BillingChoiceImageLayoutAndroid.RectangularFourByOne, String? userLocale})
const
GetBillingChoiceInfoParamsAndroid.fromJson(Map<String, dynamic> json)
factory

Properties

billingProgram BillingProgramAndroid
Billing program. Currently only BILLING_CHOICE is supported.
final
hashCode int
The hash code for this object.
no setterinherited
playBillingChoiceImageLayout BillingChoiceImageLayoutAndroid
Desired Play Billing choice image layout.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userLocale String?
BCP 47 locale tag. If omitted, Play Billing uses the user's default locale.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited