IapkitClientPayloadFormat enum

Serialization format of a public IAPKit product client payload.

Inheritance
Available extensions

Values

Toml → const IapkitClientPayloadFormat
const IapkitClientPayloadFormat('toml')
Json → const IapkitClientPayloadFormat
const IapkitClientPayloadFormat('json')
Text → const IapkitClientPayloadFormat
const IapkitClientPayloadFormat('text')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IapkitClientPayloadFormat>
A constant List of the values in this enum, in order of their declaration.