InAppMessageResultAndroid class

Result from showing Play billing in-app messages (Android) Available in OpenIAP Spec 2.1.0 / openiap-google 2.3.0 (upstream API available since Play Billing 4.1.0).

Constructors

InAppMessageResultAndroid({String? purchaseToken, required InAppMessageResponseCodeAndroid responseCode})
const
InAppMessageResultAndroid.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
purchaseToken String?
Purchase token returned when a subscription status changed.
final
responseCode InAppMessageResponseCodeAndroid
Response code for the in-app messaging flow.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited