enableBillingProgramAndroid property

BillingProgramAndroid? enableBillingProgramAndroid
final

Enable a specific billing program for Android (7.0+) When set, enables the specified billing program for external transactions.

  • USER_CHOICE_BILLING: User can select between Google Play or alternative (7.0+)
  • EXTERNAL_CONTENT_LINK: Link to external content (introduced in 8.2.0; use 8.2.1+)
  • EXTERNAL_OFFER: External offers for digital content (introduced in 8.2.0; use 8.2.1+)
  • EXTERNAL_PAYMENTS: Developer provided billing, Japan only (8.3.0+)
  • BILLING_CHOICE: Google-rendered or developer-rendered billing choice (OpenIAP Spec 2.1.0 / openiap-google 2.3.0; requires Play Billing 9.1.0+)

Implementation

final BillingProgramAndroid? enableBillingProgramAndroid;