subsequentCommitmentPaymentsCount property

int subsequentCommitmentPaymentsCount
final

Subsequent committed payments count after the subscription plan renews. For example, for a monthly subscription with subsequentCommitmentPaymentsCount of 12, users will be committed to another 12 monthly payments when the plan renews. Returns 0 if the installment plan has no subsequent commitment (reverts to normal plan).

Implementation

final int subsequentCommitmentPaymentsCount;