LaunchExternalLinkParamsAndroid class
Parameters for launching an external link (Android) Used with launchExternalLink to initiate external offer, app install, or developer-rendered Billing Choice flows Available in Google Play Billing Library 8.2.0+
Constructors
- LaunchExternalLinkParamsAndroid({required BillingProgramAndroid billingProgram, String? externalTransactionToken, required ExternalLinkLaunchModeAndroid launchMode, required ExternalLinkTypeAndroid linkType, required String linkUri})
-
const
-
LaunchExternalLinkParamsAndroid.fromJson(Map<
String, dynamic> json) -
factory
Properties
- billingProgram → BillingProgramAndroid
-
The billing program (EXTERNAL_CONTENT_LINK, EXTERNAL_OFFER, or BILLING_CHOICE)
final
- externalTransactionToken → String?
-
External transaction token for a developer-rendered Billing Choice external-link
flow. Available in OpenIAP Spec 2.1.0 / openiap-google 2.3.0
(requires Play Billing 9.1.0+). Generate it with createBillingProgramReportingDetailsAndroid.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- launchMode → ExternalLinkLaunchModeAndroid
-
The external link launch mode
final
- linkType → ExternalLinkTypeAndroid
-
The type of the external link
final
- linkUri → String
-
The URI where the content will be accessed from
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited