MutationHandlers class

Constructors

MutationHandlers({MutationAcknowledgePurchaseAndroidHandler? acknowledgePurchaseAndroid, MutationBeginRefundRequestIOSHandler? beginRefundRequestIOS, MutationClearTransactionIOSHandler? clearTransactionIOS, MutationConsumePurchaseAndroidHandler? consumePurchaseAndroid, MutationCreateBillingProgramReportingDetailsAndroidHandler? createBillingProgramReportingDetailsAndroid, MutationDeepLinkToSubscriptionsHandler? deepLinkToSubscriptions, MutationEndConnectionHandler? endConnection, MutationFinishTransactionHandler? finishTransaction, MutationInitConnectionHandler? initConnection, MutationIsBillingProgramAvailableAndroidHandler? isBillingProgramAvailableAndroid, MutationLaunchExternalLinkAndroidHandler? launchExternalLinkAndroid, MutationOpenRedeemOfferCodeAndroidHandler? openRedeemOfferCodeAndroid, MutationPresentCodeRedemptionSheetIOSHandler? presentCodeRedemptionSheetIOS, MutationPresentExternalPurchaseLinkIOSHandler? presentExternalPurchaseLinkIOS, MutationPresentExternalPurchaseNoticeSheetIOSHandler? presentExternalPurchaseNoticeSheetIOS, MutationRequestPurchaseHandler? requestPurchase, MutationRestorePurchasesHandler? restorePurchases, MutationShowBillingProgramInformationDialogAndroidHandler? showBillingProgramInformationDialogAndroid, MutationShowExternalPurchaseCustomLinkNoticeIOSHandler? showExternalPurchaseCustomLinkNoticeIOS, MutationShowInAppMessagesAndroidHandler? showInAppMessagesAndroid, MutationShowManageSubscriptionsIOSHandler? showManageSubscriptionsIOS, MutationSyncIOSHandler? syncIOS, MutationVerifyPurchaseHandler? verifyPurchase, MutationVerifyPurchaseWithProviderHandler? verifyPurchaseWithProvider})
const

Properties

acknowledgePurchaseAndroid MutationAcknowledgePurchaseAndroidHandler?
final
beginRefundRequestIOS MutationBeginRefundRequestIOSHandler?
final
clearTransactionIOS MutationClearTransactionIOSHandler?
final
consumePurchaseAndroid MutationAcknowledgePurchaseAndroidHandler?
final
createBillingProgramReportingDetailsAndroid MutationCreateBillingProgramReportingDetailsAndroidHandler?
final
deepLinkToSubscriptions MutationDeepLinkToSubscriptionsHandler?
final
endConnection MutationClearTransactionIOSHandler?
final
finishTransaction MutationFinishTransactionHandler?
final
hashCode int
The hash code for this object.
no setterinherited
initConnection MutationInitConnectionHandler?
final
isBillingProgramAvailableAndroid MutationIsBillingProgramAvailableAndroidHandler?
final
launchExternalLinkAndroid MutationLaunchExternalLinkAndroidHandler?
final
openRedeemOfferCodeAndroid MutationClearTransactionIOSHandler?
final
presentCodeRedemptionSheetIOS MutationPresentCodeRedemptionSheetIOSHandler?
final
presentExternalPurchaseLinkIOS MutationPresentExternalPurchaseLinkIOSHandler?
final
presentExternalPurchaseNoticeSheetIOS MutationPresentExternalPurchaseNoticeSheetIOSHandler?
final
requestPurchase MutationRequestPurchaseHandler?
final
restorePurchases MutationRestorePurchasesHandler?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBillingProgramInformationDialogAndroid MutationShowBillingProgramInformationDialogAndroidHandler?
final
showExternalPurchaseCustomLinkNoticeIOS MutationShowExternalPurchaseCustomLinkNoticeIOSHandler?
final
showInAppMessagesAndroid MutationShowInAppMessagesAndroidHandler?
final
showManageSubscriptionsIOS MutationShowManageSubscriptionsIOSHandler?
final
syncIOS MutationClearTransactionIOSHandler?
final
verifyPurchase MutationVerifyPurchaseHandler?
final
verifyPurchaseWithProvider MutationVerifyPurchaseWithProviderHandler?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited