showExternalPurchaseCustomLinkNoticeIOS abstract method

Future<ExternalPurchaseCustomLinkNoticeResultIOS> showExternalPurchaseCustomLinkNoticeIOS(
  1. ExternalPurchaseCustomLinkNoticeTypeIOS noticeType
)

Present the disclosure sheet required before linking out via ExternalPurchaseCustomLink (iOS 18.1+). Call this after a deliberate customer interaction before linking out to external purchases. Reference: https://developer.apple.com/documentation/storekit/externalpurchasecustomlink/shownotice(type:) See: https://www.openiap.dev/docs/apis/ios/show-external-purchase-custom-link-notice-ios

Implementation

Future<ExternalPurchaseCustomLinkNoticeResultIOS> showExternalPurchaseCustomLinkNoticeIOS(ExternalPurchaseCustomLinkNoticeTypeIOS noticeType);