PendingPurchaseUpdateAndroid class

Pending purchase update for subscription upgrades/downgrades (Android) When a user initiates a subscription change (upgrade/downgrade), the new purchase may be pending until the current billing period ends. This type contains the details of the pending change. Available in Google Play Billing Library 5.0+

Constructors

PendingPurchaseUpdateAndroid({required List<String> products, required String purchaseToken})
const
PendingPurchaseUpdateAndroid.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
products List<String>
Product IDs for the pending purchase update. These are the new products the user is switching to.
final
purchaseToken String
Purchase token for the pending transaction. Use this token to track or manage the pending purchase update.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited