purchaseToken property
Purchase token for the pending transaction. Use this token to track or manage the pending purchase update.
Implementation
final String purchaseToken;
Purchase token for the pending transaction. Use this token to track or manage the pending purchase update.
final String purchaseToken;