PurchaseAndroid class

Inheritance
Implemented types
Available extensions

Constructors

PurchaseAndroid({bool? autoRenewingAndroid, String? currentPlanId, String? dataAndroid, String? developerPayloadAndroid, required String id, List<String>? ids, bool? isAcknowledgedAndroid, required bool isAutoRenewing, String? obfuscatedAccountIdAndroid, String? obfuscatedProfileIdAndroid, String? packageNameAndroid, required IapPlatform platform, required String productId, required PurchaseState purchaseState, String? purchaseToken, required int quantity, String? signatureAndroid, required IapStore store, required double transactionDate, String? transactionId, bool? isAlternativeBilling})
const
PurchaseAndroid.fromJson(Map<String, dynamic> json)
factory

Properties

androidIsAcknowledged → bool?

Available on Purchase, provided by the PurchaseHelpers extension

no setter
androidPurchaseStateValue → int?

Available on Purchase, provided by the PurchaseHelpers extension

no setter
autoRenewingAndroid → bool?
final
currentPlanId → String?
The current plan identifier. This is:
final
dataAndroid → String?
final
developerPayloadAndroid → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
ids → List<String>?
final
iosOriginalTransactionId → String?

Available on Purchase, provided by the PurchaseHelpers extension

no setter
iosQuantity → int?

Available on Purchase, provided by the PurchaseHelpers extension

no setter
iosTransactionState → TransactionState?

Available on Purchase, provided by the PurchaseHelpers extension

no setter
isAcknowledgedAndroid → bool?
final
isAlternativeBilling → bool?
final
isAutoRenewing → bool
final
obfuscatedAccountIdAndroid → String?
final
obfuscatedProfileIdAndroid → String?
final
packageNameAndroid → String?
final
platform → IapPlatform
@deprecated Use store instead
final
productId → String
final
purchaseState → PurchaseState
final
purchaseToken → String?
Unified purchase token (iOS JWS, Android purchaseToken)
final
quantity → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatureAndroid → String?
final
store → IapStore
Store where purchase was made
final
transactionDate → double
final
transactionId → String?
final
transactionIdFor → String?

Available on Purchase, provided by the PurchaseHelpers extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInput() → PurchaseInput

Available on Purchase, provided by the PurchaseInputConversion extension

toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited