PurchaseIOS class

Inheritance
Implemented types
Available extensions

Constructors

PurchaseIOS({AdvancedCommerceInfoIOS? advancedCommerceInfoIOS, String? appAccountToken, String? appBundleIdIOS, SubscriptionBillingPlanTypeIOS? billingPlanTypeIOS, String? bundleOriginalTransactionIdIOS, String? bundleProductIdIOS, String? bundleSubscriptionGroupIdIOS, String? bundleTransactionIdIOS, TransactionCommitmentInfoIOS? commitmentInfoIOS, String? countryCodeIOS, String? currencyCodeIOS, String? currencySymbolIOS, String? currentPlanId, String? environmentIOS, double? expirationDateIOS, required String id, List<String>? ids, required bool isAutoRenewing, bool? isUpgradedIOS, PurchaseOfferIOS? offerIOS, double? originalTransactionDateIOS, String? originalTransactionIdentifierIOS, String? ownershipTypeIOS, String? previousOriginalTransactionIdIOS, required String productId, required PurchaseState purchaseState, String? purchaseToken, required int quantity, int? quantityIOS, String? reasonIOS, String? reasonStringRepresentationIOS, RenewalInfoIOS? renewalInfoIOS, double? revocationDateIOS, String? revocationReasonIOS, String? revocationTypeIOS, required IapStore store, String? storefrontCountryCodeIOS, String? subscriptionGroupIdIOS, required double transactionDate, required String transactionId, String? transactionReasonIOS, String? webOrderLineItemIdIOS, bool? isAlternativeBilling})
const
PurchaseIOS.fromJson(Map<String, dynamic> json)
factory

Properties

advancedCommerceInfoIOS AdvancedCommerceInfoIOS?
Advanced Commerce API metadata (iOS 18.4+). Present only for transactions that use the Advanced Commerce API. Contains item details, tax information, and refund data for generic SKU purchases.
final
androidIsAcknowledged bool?

Available on Purchase, provided by the PurchaseHelpers extension

no setter
androidPurchaseStateValue int?

Available on Purchase, provided by the PurchaseHelpers extension

no setter
appAccountToken String?
final
appBundleIdIOS String?
final
billingPlanTypeIOS SubscriptionBillingPlanTypeIOS?
iOS 26.4+ billing plan selected for this transaction.
final
bundleOriginalTransactionIdIOS String?
Original transaction identifier for the subscription bundle that produced this transaction (Apple 27+ SDK; back-deployed by StoreKit).
final
bundleProductIdIOS String?
Product identifier of the subscription bundle that produced this transaction.
final
bundleSubscriptionGroupIdIOS String?
Subscription-group identifier of the bundle that produced this transaction.
final
bundleTransactionIdIOS String?
Bundle transaction identifier associated with this component transaction.
final
commitmentInfoIOS TransactionCommitmentInfoIOS?
iOS 26.4+ progress information for monthly subscriptions with a 12-month commitment.
final
countryCodeIOS String?
final
currencyCodeIOS String?
final
currencySymbolIOS String?
final
currentPlanId String?
The current plan identifier. This is:
final
environmentIOS String?
final
expirationDateIOS double?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
ids List<String>?
final
iosOriginalTransactionId String?

Available on Purchase, provided by the PurchaseHelpers extension

no setter
iosQuantity int?

Available on Purchase, provided by the PurchaseHelpers extension

no setter
iosTransactionState TransactionState?

Available on Purchase, provided by the PurchaseHelpers extension

no setter
isAlternativeBilling bool?
final
isAutoRenewing bool
final
isUpgradedIOS bool?
final
offerIOS PurchaseOfferIOS?
final
originalTransactionDateIOS double?
final
originalTransactionIdentifierIOS String?
final
ownershipTypeIOS String?
StoreKit ownership raw value. Xcode 27 adds the back-deployed assigned value.
final
previousOriginalTransactionIdIOS String?
Original transaction identifier replaced when moving between a standalone subscription and a subscription bundle.
final
productId String
final
purchaseState PurchaseState
final
purchaseToken String?
Unified purchase token (iOS JWS, Android purchaseToken)
final
quantity int
final
quantityIOS int?
final
reasonIOS String?
final
reasonStringRepresentationIOS String?
final
renewalInfoIOS RenewalInfoIOS?
final
revocationDateIOS double?
final
revocationReasonIOS String?
Normalized StoreKit revocation reason, including upgraded_to_bundle.
final
revocationTypeIOS String?
StoreKit revocation type, including assignment-revocation on Apple 26.4+ when compiled with the Xcode 27 SDK.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store IapStore
Store where purchase was made
final
storefrontCountryCodeIOS String?
final
subscriptionGroupIdIOS String?
final
transactionDate double
Unix timestamp in milliseconds since January 1, 1970 UTC.
final
transactionId String
final
transactionIdFor String?

Available on Purchase, provided by the PurchaseHelpers extension

no setter
transactionReasonIOS String?
final
webOrderLineItemIdIOS String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInput() PurchaseInput

Available on Purchase, provided by the PurchaseInputConversion extension

toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited