bundleOriginalTransactionIdIOS property
Original transaction identifier for the subscription bundle that produced this transaction (Apple 27+ SDK; back-deployed by StoreKit).
Implementation
final String? bundleOriginalTransactionIdIOS;
Original transaction identifier for the subscription bundle that produced this transaction (Apple 27+ SDK; back-deployed by StoreKit).
final String? bundleOriginalTransactionIdIOS;