bundleSubscriptionGroupIdIOS property
Subscription-group identifier of the bundle that produced this transaction.
Implementation
final String? bundleSubscriptionGroupIdIOS;
Subscription-group identifier of the bundle that produced this transaction.
final String? bundleSubscriptionGroupIdIOS;