previousOriginalTransactionIdIOS property
Original transaction identifier replaced when moving between a standalone subscription and a subscription bundle.
Implementation
final String? previousOriginalTransactionIdIOS;
Original transaction identifier replaced when moving between a standalone subscription and a subscription bundle.
final String? previousOriginalTransactionIdIOS;