PurchaseOptions class

Constructors

PurchaseOptions({bool? alsoPublishToEventListenerIOS, bool? onlyIncludeActiveItemsIOS})
const
PurchaseOptions.fromJson(Map<String, dynamic> json)
factory

Properties

alsoPublishToEventListenerIOS → bool?
Also emit results through the iOS event listeners
final
hashCode → int
The hash code for this object.
no setterinherited
onlyIncludeActiveItemsIOS → bool?
Limit to currently active items on iOS
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited