QueryHandlers class

Constructors

QueryHandlers({QueryCanPresentExternalPurchaseNoticeIOSHandler? canPresentExternalPurchaseNoticeIOS, QueryCurrentEntitlementIOSHandler? currentEntitlementIOS, QueryFetchProductsHandler? fetchProducts, QueryGetActiveSubscriptionsHandler? getActiveSubscriptions, QueryGetAllTransactionsIOSHandler? getAllTransactionsIOS, QueryGetAppTransactionIOSHandler? getAppTransactionIOS, QueryGetAvailablePurchasesHandler? getAvailablePurchases, QueryGetExternalPurchaseCustomLinkTokenIOSHandler? getExternalPurchaseCustomLinkTokenIOS, QueryGetPendingTransactionsIOSHandler? getPendingTransactionsIOS, QueryGetPromotedProductIOSHandler? getPromotedProductIOS, QueryGetReceiptDataIOSHandler? getReceiptDataIOS, QueryGetStorefrontHandler? getStorefront, QueryGetStorefrontIOSHandler? getStorefrontIOS, QueryGetTransactionJwsIOSHandler? getTransactionJwsIOS, QueryHasActiveSubscriptionsHandler? hasActiveSubscriptions, QueryIsEligibleForExternalPurchaseCustomLinkIOSHandler? isEligibleForExternalPurchaseCustomLinkIOS, QueryIsEligibleForIntroOfferIOSHandler? isEligibleForIntroOfferIOS, QueryIsTransactionVerifiedIOSHandler? isTransactionVerifiedIOS, QueryLatestTransactionIOSHandler? latestTransactionIOS, QuerySubscriptionStatusIOSHandler? subscriptionStatusIOS, QueryValidateReceiptIOSHandler? validateReceiptIOS})
const

Properties

canPresentExternalPurchaseNoticeIOS MutationCheckAlternativeBillingAvailabilityAndroidHandler?
final
currentEntitlementIOS QueryCurrentEntitlementIOSHandler?
final
fetchProducts QueryFetchProductsHandler?
final
getActiveSubscriptions QueryGetActiveSubscriptionsHandler?
final
getAllTransactionsIOS MutationShowManageSubscriptionsIOSHandler?
final
getAppTransactionIOS QueryGetAppTransactionIOSHandler?
final
getAvailablePurchases QueryGetAvailablePurchasesHandler?
final
getExternalPurchaseCustomLinkTokenIOS QueryGetExternalPurchaseCustomLinkTokenIOSHandler?
final
getPendingTransactionsIOS MutationShowManageSubscriptionsIOSHandler?
final
getPromotedProductIOS QueryGetPromotedProductIOSHandler?
final
getReceiptDataIOS MutationCreateAlternativeBillingTokenAndroidHandler?
final
getStorefront QueryGetStorefrontHandler?
final
getStorefrontIOS QueryGetStorefrontHandler?
final
getTransactionJwsIOS MutationBeginRefundRequestIOSHandler?
final
hasActiveSubscriptions QueryHasActiveSubscriptionsHandler?
final
hashCode int
The hash code for this object.
no setterinherited
isEligibleForExternalPurchaseCustomLinkIOS MutationCheckAlternativeBillingAvailabilityAndroidHandler?
final
isEligibleForIntroOfferIOS MutationAcknowledgePurchaseAndroidHandler?
final
isTransactionVerifiedIOS MutationAcknowledgePurchaseAndroidHandler?
final
latestTransactionIOS QueryCurrentEntitlementIOSHandler?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionStatusIOS QuerySubscriptionStatusIOSHandler?
final
validateReceiptIOS QueryValidateReceiptIOSHandler?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited