RenewalCommitmentInfoIOS class

Constructors

RenewalCommitmentInfoIOS({required String commitmentAutoRenewProductId, required bool commitmentAutoRenewStatus, required SubscriptionBillingPlanTypeIOS commitmentRenewalBillingPlanType, required double commitmentRenewalDate, required double commitmentRenewalPrice})
const
RenewalCommitmentInfoIOS.fromJson(Map<String, dynamic> json)
factory

Properties

commitmentAutoRenewProductId String
final
commitmentAutoRenewStatus bool
final
commitmentRenewalBillingPlanType SubscriptionBillingPlanTypeIOS
final
commitmentRenewalDate double
final
commitmentRenewalPrice double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited