bundleOriginalTransactionId property
Original transaction identifier for the bundle used by the next renewal.
Implementation
final String? bundleOriginalTransactionId;
Original transaction identifier for the bundle used by the next renewal.
final String? bundleOriginalTransactionId;