bundleSubscriptionGroupId property
Subscription-group identifier for the bundle used by the next renewal.
Implementation
final String? bundleSubscriptionGroupId;
Subscription-group identifier for the bundle used by the next renewal.
final String? bundleSubscriptionGroupId;