commitmentInfo property
iOS 26.4+ renewal commitment metadata for monthly subscriptions with a 12-month commitment.
Implementation
final RenewalCommitmentInfoIOS? commitmentInfo;
iOS 26.4+ renewal commitment metadata for monthly subscriptions with a 12-month commitment.
final RenewalCommitmentInfoIOS? commitmentInfo;