RentalDetailsAndroid class

Rental details for one-time purchase products that can be rented (Android) Available in Google Play Billing Library 8.0+

Constructors

RentalDetailsAndroid({String? rentalExpirationPeriod, required String rentalPeriod})
const
RentalDetailsAndroid.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
rentalExpirationPeriod → String?
Rental expiration period in ISO 8601 format Time after rental period ends when user can still extend
final
rentalPeriod → String
Rental period in ISO 8601 format (e.g., P7D for 7 days)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited