RequestPurchaseAndroidProps class

Constructors

RequestPurchaseAndroidProps({bool? isOfferPersonalized, String? obfuscatedAccountIdAndroid, String? obfuscatedProfileIdAndroid, required List<String> skus})
const
RequestPurchaseAndroidProps.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isOfferPersonalized → bool?
Personalized offer flag
final
obfuscatedAccountIdAndroid → String?
Obfuscated account ID
final
obfuscatedProfileIdAndroid → String?
Obfuscated profile ID
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skus → List<String>
List of product SKUs
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited