RequestPurchaseIosProps class

Constructors

RequestPurchaseIosProps({bool? andDangerouslyFinishTransactionAutomatically, String? appAccountToken, int? quantity, required String sku, DiscountOfferInputIOS? withOffer})
const
RequestPurchaseIosProps.fromJson(Map<String, dynamic> json)
factory

Properties

andDangerouslyFinishTransactionAutomatically → bool?
Auto-finish transaction (dangerous)
final
appAccountToken → String?
App account token for user tracking
final
hashCode → int
The hash code for this object.
no setterinherited
quantity → int?
Purchase quantity
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku → String
Product SKU
final
withOffer → DiscountOfferInputIOS?
Discount offer to apply
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited