billingPlanType property
Billing plan to use when purchasing an annual subscription that offers monthly billing with a 12-month commitment (iOS 26.4+).
Implementation
final SubscriptionBillingPlanTypeIOS? billingPlanType;
Billing plan to use when purchasing an annual subscription that offers monthly billing with a 12-month commitment (iOS 26.4+).
final SubscriptionBillingPlanTypeIOS? billingPlanType;