RequestSubscriptionPropsByPlatforms class

Properties

android → RequestSubscriptionAndroidProps?
@deprecated Use google instead
final
apple → RequestSubscriptionIosProps?
Apple-specific subscription parameters
final
google → RequestSubscriptionAndroidProps?
Google-specific subscription parameters
final
hashCode → int
The hash code for this object.
no setterinherited
ios → RequestSubscriptionIosProps?
@deprecated Use apple instead
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited