RequestVerifyPurchaseWithIapkitAmazonProps class
Properties
-
expectedProductId
→ String?
-
Available in OpenIAP Spec 3.2.0 / openiap-apple 3.2.0 / openiap-google 3.3.0.
Optional Amazon product id that must match the product id verified by RVS.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
receiptId
→ String
-
Amazon Appstore receipt id returned by PurchaseResponse.getReceipt().getReceiptId().
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sandbox
→ bool?
-
Use Amazon RVS Cloud Sandbox for App Tester receipts.
final
-
userId
→ String?
-
Amazon Appstore user id returned by PurchaseResponse.getUserData().getUserId().
final