SubscriptionBillingPlanTypeIOS enum

Inheritance
Available extensions

Values

Unknown → const SubscriptionBillingPlanTypeIOS

Unknown or unsupported billing plan type.

const SubscriptionBillingPlanTypeIOS('unknown')
Monthly → const SubscriptionBillingPlanTypeIOS

Monthly billing with a 12-month commitment.

const SubscriptionBillingPlanTypeIOS('monthly')
UpFront → const SubscriptionBillingPlanTypeIOS

Up-front billing for the full subscription period.

const SubscriptionBillingPlanTypeIOS('up-front')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubscriptionBillingPlanTypeIOS>
A constant List of the values in this enum, in order of their declaration.