TransactionCommitmentInfoIOS class

Constructors

TransactionCommitmentInfoIOS({required int billingPeriodNumber, required double commitmentExpiresDate, required double commitmentPrice, required int totalBillingPeriods})
const
TransactionCommitmentInfoIOS.fromJson(Map<String, dynamic> json)
factory

Properties

billingPeriodNumber int
final
commitmentExpiresDate double
final
commitmentPrice double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBillingPeriods int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited