isValid property
bool
get
isValid
Whether the purchase is valid, without inspecting the concrete result variant.
Implementation
bool get isValid;
Whether the purchase is valid, without inspecting the concrete result variant.
bool get isValid;