VerifyPurchaseResultIOS class

Inheritance
Implemented types

Constructors

VerifyPurchaseResultIOS({required bool isValid, required String jwsRepresentation, Purchase? latestTransaction, required String receiptData})
const
VerifyPurchaseResultIOS.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isValid → bool
Whether the receipt is valid
final
jwsRepresentation → String
JWS representation
final
latestTransaction → Purchase?
Latest transaction if available
final
receiptData → String
Receipt data string
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited