subscriptionState property
Normalized subscription state at the time of event, when the event refers to a subscription. Null for one-time purchase events.
Implementation
final SubscriptionState? subscriptionState;
Normalized subscription state at the time of event, when the event refers to a subscription. Null for one-time purchase events.
final SubscriptionState? subscriptionState;