RequestPurchaseIosBuilder class
Builder for iOS-specific purchase props
Constructors
Properties
- advancedCommerceData ↔ String?
-
getter/setter pair
- andDangerouslyFinishTransactionAutomatically ↔ bool?
-
getter/setter pair
- appAccountToken ↔ String?
-
getter/setter pair
- billingPlanType ↔ SubscriptionBillingPlanTypeIOS?
-
Billing plan for annual subscriptions with monthly commitment (iOS 26.4+)
getter/setter pair
- compactJWS ↔ String?
-
Compact JWS for overriding introductory offer eligibility when this
builder is used with subscriptions (iOS 15+)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- promotionalOfferJWS ↔ PromotionalOfferJWSInputIOS?
-
JWS promotional offer when this builder is used with subscriptions
(iOS 15+, WWDC 2025)
getter/setter pair
- quantity ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sku ↔ String
-
getter/setter pair
- winBackOffer ↔ WinBackOfferInputIOS?
-
Win-back offer to apply when this builder is used with subscriptions
(iOS 18+)
getter/setter pair
- withOffer ↔ DiscountOfferInputIOS?
-
getter/setter pair
Methods
-
build(
) → RequestPurchaseIosProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited