RequestSubscriptionIosBuilder class

Builder for iOS-specific subscription props

Properties

andDangerouslyFinishTransactionAutomatically ↔ bool?
getter/setter pair
appAccountToken ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
quantity ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku ↔ String
getter/setter pair
withOffer ↔ DiscountOfferInputIOS?
getter/setter pair

Methods

build() → RequestSubscriptionIosProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited