TypeInApp enum
An enumeration of legacy in-app purchase types for Android.
Use the generated ProductQueryType contract. Scheduled for removal in flutter_inapp_purchase 10.0.0.
- Inheritance
- Available extensions
- Annotations
-
- @Deprecated('Use ProductQueryType. ' 'Scheduled for removal in flutter_inapp_purchase 10.0.0.')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited