PurchaseResult class
Legacy error payload used by FlutterInappPurchase.purchaseError.
Use PurchaseError from purchaseErrorListener. Scheduled for removal in
flutter_inapp_purchase 10.0.0.
- Annotations
-
- @Deprecated('Use PurchaseError from purchaseErrorListener. ' 'Scheduled for removal in flutter_inapp_purchase 10.0.0.')
Constructors
-
PurchaseResult({int? responseCode, String? debugMessage, String? code, String? message, String? productId, List<
String> ? productIds, String? productType, bool? isEmptyProductList, SubResponseCodeAndroid? subResponseCodeAndroid, String? purchaseTokenAndroid}) -
PurchaseResult.fromJSON(Map<
String, dynamic> json) -
factory
Properties
- code → String?
-
final
- debugMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmptyProductList → bool?
-
final
- message → String?
-
final
- productId → String?
-
final
-
productIds
→ List<
String> ? -
final
- productType → String?
-
final
- purchaseTokenAndroid → String?
-
final
- responseCode → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subResponseCodeAndroid → SubResponseCodeAndroid?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited