BillingChoiceScreenTypeAndroid enum
Choice screen renderer for Billing Choice availability (Android) Available in OpenIAP Spec 2.1.0 / openiap-google 2.3.0 (requires Play Billing 9.1.0+).
Values
- Unspecified → const BillingChoiceScreenTypeAndroid
-
Unspecified choice screen type.
const BillingChoiceScreenTypeAndroid('unspecified') - DeveloperRendered → const BillingChoiceScreenTypeAndroid
-
Choice screen is rendered by the developer app.
const BillingChoiceScreenTypeAndroid('developer-rendered') - GoogleRendered → const BillingChoiceScreenTypeAndroid
-
Choice screen is rendered by Google Play.
const BillingChoiceScreenTypeAndroid('google-rendered')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BillingChoiceScreenTypeAndroid> - A constant List of the values in this enum, in order of their declaration.