BillingProgramAvailabilityResultAndroid class
Result of checking billing program availability (Android) Available in Google Play Billing Library 8.2.0+
Constructors
- BillingProgramAvailabilityResultAndroid({required BillingProgramAndroid billingProgram, BillingChoiceScreenTypeAndroid? choiceScreenType, required bool isAvailable, bool? isExternalLinkAvailable})
-
const
-
BillingProgramAvailabilityResultAndroid.fromJson(Map<
String, dynamic> json) -
factory
Properties
- billingProgram → BillingProgramAndroid
-
The billing program that was checked
final
- choiceScreenType → BillingChoiceScreenTypeAndroid?
-
Billing Choice screen renderer. Populated only for available BILLING_CHOICE results.
Available in OpenIAP Spec 2.1.0 / openiap-google 2.3.0.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAvailable → bool
-
Whether the billing program is available for the user
final
- isExternalLinkAvailable → bool?
-
Whether external-link payment is available for Billing Choice.
Populated only for available BILLING_CHOICE results.
Available in OpenIAP Spec 2.1.0 / openiap-google 2.3.0.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited