BundledSubscriptionIOS class

Metadata for one auto-renewable subscription included in an Apple subscription bundle (Apple 27+ beta).

Constructors

BundledSubscriptionIOS({required String description, required String displayName, required String displayPrice, required String id, required bool isFamilyShareable, required double price, required String subscriptionGroupDisplayName, required String subscriptionGroupId, required int subscriptionGroupLevel})
const
BundledSubscriptionIOS.fromJson(Map<String, dynamic> json)
factory

Properties

description String
final
displayName String
final
displayPrice String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isFamilyShareable bool
final
price double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionGroupDisplayName String
final
subscriptionGroupId String
final
subscriptionGroupLevel int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited