DeveloperBillingTypeAndroid enum

Developer-provided billing destination type for Billing Program reporting details (Android) Available in OpenIAP Spec 2.1.0 / openiap-google 2.3.0 (requires Play Billing 9.1.0+).

Inheritance
Available extensions

Values

DeveloperBillingTypeUnspecified → const DeveloperBillingTypeAndroid

Unspecified developer billing type. Do not use.

const DeveloperBillingTypeAndroid('developer-billing-type-unspecified')
InApp → const DeveloperBillingTypeAndroid

Developer-provided billing via native in-app experience.

const DeveloperBillingTypeAndroid('in-app')

Developer-provided billing via external link or embedded web browsing.

const DeveloperBillingTypeAndroid('external-link')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DeveloperBillingTypeAndroid>
A constant List of the values in this enum, in order of their declaration.