DeveloperProvidedBillingDetailsAndroid class
Details provided when user selects developer billing option (Android) Received via DeveloperProvidedBillingListener callback Available in Google Play Billing Library 8.3.0+
Constructors
-
DeveloperProvidedBillingDetailsAndroid({String? externalTransactionToken, String? linkUri, String? originalExternalTransactionId, required List<
DeveloperProvidedBillingProductAndroid> products}) -
const
-
DeveloperProvidedBillingDetailsAndroid.fromJson(Map<
String, dynamic> json) -
factory
Properties
- externalTransactionToken → String?
-
External transaction token used to report transactions made through developer billing.
Nullable for flows such as external payments where no token is returned.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- linkUri → String?
-
URI to launch for an external-link Billing Choice flow, when provided by
Google Play.
final
- originalExternalTransactionId → String?
-
Original external transaction ID when replacing a subscription that was
purchased through developer billing.
final
-
products
→ List<
DeveloperProvidedBillingProductAndroid> -
Products selected for the developer billing flow.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited