InAppMessageResponseCodeAndroid enum
Response code from Play billing in-app messages (Android) Available in OpenIAP Spec 2.1.0 / openiap-google 2.3.0 (upstream API available since Play Billing 4.1.0).
Values
- NoActionNeeded → const InAppMessageResponseCodeAndroid
-
Flow finished and no developer action is needed.
const InAppMessageResponseCodeAndroid('no-action-needed') - SubscriptionStatusUpdated → const InAppMessageResponseCodeAndroid
-
Subscription status changed and the purchase token should be checked.
const InAppMessageResponseCodeAndroid('subscription-status-updated')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
InAppMessageResponseCodeAndroid> - A constant List of the values in this enum, in order of their declaration.