InitConnectionConfig class

Connection initialization configuration

Constructors

InitConnectionConfig({AlternativeBillingModeAndroid? alternativeBillingModeAndroid})
const
InitConnectionConfig.fromJson(Map<String, dynamic> json)
factory

Properties

alternativeBillingModeAndroid → AlternativeBillingModeAndroid?
Alternative billing mode for Android If not specified, defaults to NONE (standard Google Play billing)
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited