InstallmentPlanDetailsAndroid class
Installment plan details for subscription offers (Android) Contains information about the installment plan commitment. Available in Google Play Billing Library 7.0+
Constructors
- InstallmentPlanDetailsAndroid({required int commitmentPaymentsCount, required int subsequentCommitmentPaymentsCount})
-
const
-
InstallmentPlanDetailsAndroid.fromJson(Map<
String, dynamic> json) -
factory
Properties
- commitmentPaymentsCount → int
-
Committed payments count after a user signs up for this subscription plan.
For example, for a monthly subscription with commitmentPaymentsCount of 12,
users will be charged monthly for 12 months after signup.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subsequentCommitmentPaymentsCount → int
-
Subsequent committed payments count after the subscription plan renews.
For example, for a monthly subscription with subsequentCommitmentPaymentsCount of 12,
users will be committed to another 12 monthly payments when the plan renews.
Returns 0 if the installment plan has no subsequent commitment (reverts to normal plan).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited