createAlternativeBillingTokenAndroid abstract method
Create a reporting token for an alternative billing flow. Step 3 of the alternative billing flow. Must be called AFTER successful payment in your payment system. Token must be reported to Google Play backend within 24 hours.
Returns token string, or null if creation failed. Throws OpenIapError.NotPrepared if billing client not ready. See: https://www.openiap.dev/docs/apis/android/create-alternative-billing-token-android
Implementation
Future<String?> createAlternativeBillingTokenAndroid();