showInAppMessagesAndroid abstract method
Future<InAppMessageResultAndroid>
showInAppMessagesAndroid({
- List<
InAppMessageCategoryAndroid> ? categories,
Overlay Play billing in-app messages, such as payment issues or subscription price-change confirmations. OpenIAP availability: Spec 2.1.0 / openiap-google 2.3.0 (upstream API available since Play Billing 4.1.0). Returns a response code and, when the subscription status changes, the related purchase token. Throws OpenIapError.NotPrepared if billing client not ready. See: https://openiap.dev/docs/apis/android/show-in-app-messages-android
Implementation
Future<InAppMessageResultAndroid> showInAppMessagesAndroid({
List<InAppMessageCategoryAndroid>? categories,
});