RequestSubscriptionAndroidProps class

Constructors

RequestSubscriptionAndroidProps({bool? isOfferPersonalized, String? obfuscatedAccountIdAndroid, String? obfuscatedProfileIdAndroid, String? purchaseTokenAndroid, int? replacementModeAndroid, required List<String> skus, List<AndroidSubscriptionOfferInput>? subscriptionOffers})
const
RequestSubscriptionAndroidProps.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isOfferPersonalized → bool?
Personalized offer flag
final
obfuscatedAccountIdAndroid → String?
Obfuscated account ID
final
obfuscatedProfileIdAndroid → String?
Obfuscated profile ID
final
purchaseTokenAndroid → String?
Purchase token for upgrades/downgrades
final
replacementModeAndroid → int?
Replacement mode for subscription changes
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skus → List<String>
List of subscription SKUs
final
subscriptionOffers → List<AndroidSubscriptionOfferInput>?
Subscription offers
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited