RequestSubscriptionIosProps class
Constructors
-
RequestSubscriptionIosProps({String? advancedCommerceData, bool? andDangerouslyFinishTransactionAutomatically, String? appAccountToken, SubscriptionBillingPlanTypeIOS? billingPlanType, String? compactJWS, PromotionalOfferJWSInputIOS? promotionalOfferJWS, int? quantity, required String sku, WinBackOfferInputIOS? winBackOffer, DiscountOfferInputIOS? withOffer})
-
const
-
RequestSubscriptionIosProps.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
advancedCommerceData
→ String?
-
Advanced commerce data token (iOS 15+).
Used with StoreKit 2's Product.PurchaseOption.custom API for passing
campaign tokens, affiliate IDs, or other attribution data.
The data is formatted as JSON: {"signatureInfo": {"token": "
final
-
andDangerouslyFinishTransactionAutomatically
→ bool?
-
final
-
appAccountToken
→ String?
-
final
-
billingPlanType
→ SubscriptionBillingPlanTypeIOS?
-
Billing plan to use when purchasing an annual subscription that offers
monthly billing with a 12-month commitment (iOS 26.4+).
final
-
compactJWS
→ String?
-
Compact JWS string for overriding introductory offer eligibility
(iOS 15+, WWDC 2025). When nil, the system determines eligibility.
Generate the JWS on your server and pass it to StoreKit's
introductoryOfferEligibility(compactJWS:) purchase option.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
promotionalOfferJWS
→ PromotionalOfferJWSInputIOS?
-
JWS promotional offer (iOS 15+, WWDC 2025).
New signature format using compact JWS string for promotional offers.
Back-deployed to iOS 15.
final
-
quantity
→ int?
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sku
→ String
-
final
-
winBackOffer
→ WinBackOfferInputIOS?
-
Win-back offer to apply (iOS 18+)
Used to re-engage churned subscribers with a discount or free trial.
The offer is available when the customer is eligible and can be discovered
via StoreKit Message (automatic) or subscription offer APIs.
final
-
withOffer
→ DiscountOfferInputIOS?
-
Promotional offer to apply for subscription purchases.
Requires server-signed offer with nonce, timestamp, keyId, and signature.
final