RequestSubscriptionIosProps class

Constructors

RequestSubscriptionIosProps({bool? andDangerouslyFinishTransactionAutomatically, String? appAccountToken, int? quantity, required String sku, DiscountOfferInputIOS? withOffer})
const
RequestSubscriptionIosProps.fromJson(Map<String, dynamic> json)
factory

Properties

andDangerouslyFinishTransactionAutomatically → bool?
final
appAccountToken → String?
final
hashCode → int
The hash code for this object.
no setterinherited
quantity → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku → String
final
withOffer → DiscountOfferInputIOS?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited