RequestVerifyPurchaseWithIapkitAmazonProps class
Constructors
- RequestVerifyPurchaseWithIapkitAmazonProps({required String receiptId, bool? sandbox, String? userId})
-
const
-
RequestVerifyPurchaseWithIapkitAmazonProps.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- receiptId → String
-
Amazon Appstore receipt id returned by PurchaseResponse.getReceipt().getReceiptId().
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sandbox → bool?
-
Use Amazon RVS Cloud Sandbox for App Tester receipts.
final
- userId → String?
-
Amazon Appstore user id returned by PurchaseResponse.getUserData().getUserId().
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited