RequestVerifyPurchaseWithIapkitHorizonProps class
Constructors
- RequestVerifyPurchaseWithIapkitHorizonProps({required String sku, String? userId})
-
const
-
RequestVerifyPurchaseWithIapkitHorizonProps.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sku → String
-
Meta Horizon product or subscription SKU.
final
- userId → String?
-
Meta app-scoped user ID. The openiap-google Horizon module resolves the logged-in user when omitted.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited