RequestVerifyPurchaseWithIapkitProps class
Platform-specific verification parameters for IAPKit.
- apple: Verifies via App Store (JWS token)
- google: Verifies via Play Store (purchase token)
- amazon: Verifies via Amazon Appstore RVS (userId + receiptId)
Constructors
- RequestVerifyPurchaseWithIapkitProps({RequestVerifyPurchaseWithIapkitAmazonProps? amazon, String? apiKey, RequestVerifyPurchaseWithIapkitAppleProps? apple, String? baseUrl, RequestVerifyPurchaseWithIapkitGoogleProps? google})
-
const
-
RequestVerifyPurchaseWithIapkitProps.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amazon → RequestVerifyPurchaseWithIapkitAmazonProps?
-
Amazon Appstore verification parameters.
final
- apiKey → String?
-
API key used for the Authorization header (Bearer {apiKey}).
final
- apple → RequestVerifyPurchaseWithIapkitAppleProps?
-
Apple App Store verification parameters.
final
- baseUrl → String?
-
Available in OpenIAP Spec 2.3.1 / openiap-apple 2.4.0 / openiap-google 2.4.0.
Base URL for the IAPKit server. Defaults to https://kit.openiap.dev.
Set this to a reachable HTTP(S) origin when self-hosting or testing a local IAPKit server.
The apiKey must be issued by the same IAPKit/Convex deployment as this server.
final
- google → RequestVerifyPurchaseWithIapkitGoogleProps?
-
Google Play Store verification parameters.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited