RequestVerifyPurchaseWithIapkitProps class

Properties

apiKey → String?
API key used for the Authorization header (Bearer {apiKey}).
final
apple → RequestVerifyPurchaseWithIapkitAppleProps?
Apple verification parameters.
final
google → RequestVerifyPurchaseWithIapkitGoogleProps?
Google verification parameters.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited