SubscriptionPricingTermsIOS class

Constructors

SubscriptionPricingTermsIOS({required String billingDisplayPrice, required SubscriptionPeriodValueIOS billingPeriod, required SubscriptionBillingPlanTypeIOS billingPlanType, required double billingPrice, required SubscriptionCommitmentInfoIOS commitmentInfo, List<SubscriptionOffer>? subscriptionOffers})
const
SubscriptionPricingTermsIOS.fromJson(Map<String, dynamic> json)
factory

Properties

billingDisplayPrice String
final
billingPeriod SubscriptionPeriodValueIOS
final
billingPlanType SubscriptionBillingPlanTypeIOS
final
billingPrice double
final
commitmentInfo SubscriptionCommitmentInfoIOS
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionOffers List<SubscriptionOffer>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited