SubscriptionResolver class abstract

GraphQL root subscription operations.

Constructors

SubscriptionResolver()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
promotedProductIOS() → Future<String>
Fires when the App Store surfaces a promoted product (iOS only)
purchaseError() → Future<PurchaseError>
Fires when a purchase fails or is cancelled
purchaseUpdated() → Future<Purchase>
Fires when a purchase completes successfully or a pending purchase resolves
toString() → String
A string representation of this object.
inherited
userChoiceBillingAndroid() → Future<UserChoiceBillingDetails>
Fires when a user selects alternative billing in the User Choice Billing dialog (Android only) Only triggered when the user selects alternative billing instead of Google Play billing

Operators

operator ==(Object other) → bool
The equality operator.
inherited