SubscriptionState enum
Values
- Active → const SubscriptionState
-
const SubscriptionState('active') - InGracePeriod → const SubscriptionState
-
const SubscriptionState('in-grace-period') - InBillingRetry → const SubscriptionState
-
const SubscriptionState('in-billing-retry') - Expired → const SubscriptionState
-
const SubscriptionState('expired') - Revoked → const SubscriptionState
-
const SubscriptionState('revoked') - Refunded → const SubscriptionState
-
const SubscriptionState('refunded') - Paused → const SubscriptionState
-
const SubscriptionState('paused') - Unknown → const SubscriptionState
-
const SubscriptionState('unknown')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SubscriptionState> - A constant List of the values in this enum, in order of their declaration.